<?php
/**
 * Template part for displaying posts
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package MagLink
 */



$enable_single_author_meta = maglink_get_option('enable_single_author_meta');
$select_single_author_meta = maglink_get_option('select_single_author_meta');
$single_author_meta_title = maglink_get_option('single_author_meta_title');

$enable_single_date_meta = maglink_get_option('enable_single_date_meta');
$select_single_date = maglink_get_option('select_single_date');
$single_date_meta_title = maglink_get_option('single_date_meta_title');
$select_single_date_format = maglink_get_option('select_single_date_format');

$enable_single_category_meta = maglink_get_option('enable_single_category_meta');
$single_category_label = maglink_get_option('single_category_label');
$select_single_category_color = maglink_get_option('select_single_category_color');
$enable_single_read_time_meta = maglink_get_option('enable_single_read_time_meta');
$enable_single_tag_meta = maglink_get_option('enable_single_tag_meta');

$show_sticky_article_navigation = maglink_get_option('show_sticky_article_navigation');
$show_related_posts = maglink_get_option('show_related_posts');
$show_author_posts = maglink_get_option('show_author_posts');
$show_author_info = maglink_get_option('show_author_info');

$maglink_post_navigation = get_post_meta($post->ID, 'maglink_single_post_navigation', true);
$maglink_single_category_meta = get_post_meta($post->ID, 'maglink_single_category_meta', true);
$maglink_single_date_meta = get_post_meta($post->ID, 'maglink_single_date_meta', true);
$maglink_single_author_meta = get_post_meta($post->ID, 'maglink_single_author_meta', true);
$maglink_single_related_post = get_post_meta($post->ID, 'maglink_single_related_post', true);
$maglink_single_author_post = get_post_meta($post->ID, 'maglink_single_author_post', true);
$maglink_single_post_author = get_post_meta($post->ID, 'maglink_single_post_author_info', true);
?>

<article id="post-<?php the_ID(); ?>" <?php post_class('wpi-post wpi-post-default'); ?>>
    <?php maglink_get_breadcrumb(); ?>
    <?php maglink_post_thumbnail(); ?>
    <div class="entry-details">
        <header class="entry-header">
            <?php
            if ($maglink_single_category_meta == 1) {
                maglink_post_category($select_single_category_color, $single_category_label);
            } elseif ($maglink_single_category_meta == '') {
                if ($enable_single_category_meta) {
                    maglink_post_category($select_single_category_color, $single_category_label);
                }
            } elseif ($maglink_single_category_meta == 0) {
            }

            ?>
            <?php
            if (!$enable_single_read_time_meta) {
                maglink_get_readtime();
            } ?>
            <?php
            the_title('<h1 class="entry-title entry-title-large">', '</h1>');

            if ('post' === get_post_type()):
                ?>
                <div class="entry-meta-wrapper">
                    <?php
                    if ($maglink_single_date_meta == 1) {
                        maglink_posted_on($select_single_date_format, $single_date_meta_title, $select_single_date);
                    } elseif ($maglink_single_date_meta == '') {
                        if ($enable_single_date_meta) {
                            maglink_posted_on($select_single_date_format, $single_date_meta_title, $select_single_date);
                        }
                    } elseif ($maglink_single_date_meta == 0) {
                    }
                    ?>

                    <?php
                    if ($maglink_single_author_meta == 1) {
                        echo '<div class="entry-meta-separator"></div>';
                        maglink_posted_by($select_single_author_meta, $single_author_meta_title);
                    } elseif ($maglink_single_author_meta == '') {
                        if ($enable_single_author_meta) {
                            echo '<div class="entry-meta-separator"></div>';
                            maglink_posted_by($select_single_author_meta, $single_author_meta_title);
                        }
                    } elseif ($maglink_single_author_meta == 0) {
                    }
                    ?>
                </div><!-- .entry-meta -->
            <?php endif; ?>
        </header><!-- .entry-header -->

        <div class="entry-content">
            <?php
            the_content(
                sprintf(
                    wp_kses(
                        /* translators: %s: Name of current post. Only visible to screen readers */
                        __('Continue reading<span class="screen-reader-text"> "%s"</span>', 'maglink'),
                        array(
                            'span' => array(
                                'class' => array(),
                            ),
                        )
                    ),
                    wp_kses_post(get_the_title())
                )
            );

            wp_link_pages(
                array(
                    'before' => '<div class="page-links">' . esc_html__('Pages:', 'maglink'),
                    'after' => '</div>',
                )
            );
            ?>
        </div><!-- .entry-content -->

        <footer class="entry-footer">
            <?php maglink_entry_footer($enable_single_tag_meta); ?>
        </footer><!-- .entry-footer -->
    </div>
</article><!-- #post-<?php the_ID(); ?> -->

<?php
if ('post' === get_post_type()):

    if ($maglink_single_post_author == 1) {
        get_template_part('template-parts/single/single-author-info');
    } elseif ($maglink_single_post_author == '') {
        if ($show_author_info) {
            get_template_part('template-parts/single/single-author-info');
        }
    } elseif ($maglink_single_post_author == 0) {
    }


    if ($maglink_single_related_post == 1) {
        get_template_part('template-parts/single/single-related-posts');
    } elseif ($maglink_single_related_post == '') {
        if ($show_related_posts) {
            get_template_part('template-parts/single/single-related-posts');
        }
    } elseif ($maglink_single_related_post == 0) {
    }

    if ($maglink_single_author_post == 1) {
        get_template_part('template-parts/single/single-author-posts');
    } elseif ($maglink_single_author_post == '') {
        if ($show_author_posts) {
            get_template_part('template-parts/single/single-author-posts');
        }
    } elseif ($maglink_single_author_post == 0) {
    }

endif;
?>

<?php
if ($maglink_post_navigation == 1) {
    get_template_part('template-parts/single/sticky-article-nav');
} elseif ($maglink_post_navigation == '') {
    if ($show_sticky_article_navigation) {
        get_template_part('template-parts/single/sticky-article-nav');
    }
} elseif ($maglink_post_navigation == 0) {
}
?>